aboutsummaryrefslogtreecommitdiff
path: root/tccpp.c
diff options
context:
space:
mode:
Diffstat (limited to 'tccpp.c')
-rw-r--r--tccpp.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/tccpp.c b/tccpp.c
index ebbd051..6446c9c 100644
--- a/tccpp.c
+++ b/tccpp.c
@@ -1280,17 +1280,18 @@ static int macro_is_equal(const int *a, const int *b)
{
CValue cv;
int t;
+ static CString localbuf;
if (!a || !b)
return 1;
while (*a && *b) {
- /* first time preallocate static cstr_buf, next time only reset position to start */
- cstr_reset(&cstr_buf);
+ /* first time preallocate static localbuf, next time only reset position to start */
+ cstr_reset(&localbuf);
TOK_GET(&t, &a, &cv);
- cstr_cat(&cstr_buf, get_tok_str(t, &cv), 0);
+ cstr_cat(&localbuf, get_tok_str(t, &cv), 0);
TOK_GET(&t, &b, &cv);
- if (strcmp(cstr_buf.data, get_tok_str(t, &cv)))
+ if (strcmp(localbuf.data, get_tok_str(t, &cv)))
return 0;
}
return !(*a || *b);